@@ -4,12 +4,15 @@ import sys
 from jinja2 import Template
 
 from typing import Optional, List, Dict
+
 from simple_ddl_parser import DDLParser, parse_from_file
 from omymodels.gino import core as g
 from omymodels.pydantic import core as p
 from omymodels.dataclass import core as d
 from omymodels.sqlalchemy import core as s
 from omymodels.sqlalchemy_core import core as sc
+from omymodels.meta_model import TableMeta, Type
+from omymodels.errors import NoTablesError
 
 
 def get_tables_information(
@@ -37,15 +40,18 @@ def create_models(
     models_type: str = "gino",
     schema_global: Optional[bool] = True,
     defaults_off: Optional[bool] = False,
+    exit_silent: Optional[bool] = False,
 ):
     """ models_type can be: "gino", "dataclass", "pydantic" """
     # extract data from ddl file
     data = get_tables_information(ddl, ddl_path)
-    print(data)
-    if not data['tables'] or data['tables'][0].get("schema", 'NOT EXIST') == 'NOT EXIST':
-        print("No tables found in DDL. Exit.")
-        sys.exit(0)
     data = remove_quotes_from_strings(data)
+    data = convert_ddl_to_models(data)
+    if not data["tables"]:
+        if exit_silent:
+            sys.exit(0)
+        else:
+            raise NoTablesError()
     # generate code
     output = generate_models_file(
         data, singular, naming_exceptions, models_type, schema_global, defaults_off
@@ -57,6 +63,19 @@ def create_models(
     return {"metadata": data, "code": output}
 
 
+def convert_ddl_to_models(data):
+    final_data = {"tables": [], "types": []}
+    tables = []
+    for table in data["tables"]:
+        tables.append(TableMeta(**table))
+    final_data["tables"] = tables
+    _types = []
+    for _type in data["types"]:
+        _types.append(Type(**_type))
+    final_data["types"] = _types
+    return final_data
+
+
 def save_models_to_file(models: str, dump_path: str) -> None:
     folder = os.path.dirname(dump_path)
     if folder:
@@ -104,13 +123,14 @@ def generate_models_file(
 
 
 def render_jinja2_template(models_type: str, models: str, headers: str) -> str:
-    template_file = pathlib.Path(__file__).parent / models_type / f'{models_type}.jinja2'
+    template_file = (
+        pathlib.Path(__file__).parent / models_type / f"{models_type}.jinja2"
+    )
 
     with open(template_file) as t:
         template = t.read()
         template = Template(template)
-        params = {"models": models,
-                  "headers": headers}
+        params = {"models": models, "headers": headers}
         return template.render(**params)
 
 
