@@ -1,7 +1,3 @@
-postgresql_dialect = ["ARRAY", "JSON", "JSONB"]
-
-# key - type from ddl, value - type from GinoORM
-
 types_mapping = {
     "varchar": "db.String",
     "float": "db.Float",
@@ -27,6 +23,7 @@ types_mapping = {
     "int": "db.Integer",
     "serial": "db.Integer",
     "bigserial": "db.BigInteger",
+    "uuid": "UUID",
 }
 
 
