@@ -34,10 +34,10 @@ table_args = """
 
 """
 fk_constraint_template = """
-    {fk_name} = db.ForeignKeyConstraint(
+    {fk_name} = sa.ForeignKeyConstraint(
         [{fk_columns}], [{fk_references_columns}])
 """
-fk_in_column = ", db.ForeignKey('{ref_table}.{ref_column}')"
+fk_in_column = ", sa.ForeignKey('{ref_table}.{ref_column}')"
 unique_index_template = """
     UniqueConstraint({columns}, name={name})"""
 
